@@ -41,6 +41,7 @@ struct _AppletConfig {
 	gboolean bEnablePopUp;
 	gboolean bEnableAnimateIcon;
 	gboolean bEnableNewModule;
+	gboolean bLaunchLauncherAPIDaemon;
 	} ;
 
 
@@ -61,7 +62,7 @@ struct _dbusApplet {
 	GObject parent;
 	DBusGConnection *connection;
 	DBusGProxy *proxy;
-	CairoDockModuleInstance *pModuleInstance;
+	GldiModuleInstance *pModuleInstance;
 	gchar *cModuleName;
 	gint id;
 	gchar *cBusPath;
@@ -100,16 +101,34 @@ typedef enum {
 	NB_SIGNALS
 } CDSignalEnum;
 
+
+#ifdef DBUSMENU_GTK_FOUND
+#if (GTK_MAJOR_VERSION < 3) || defined (DBUSMENU_GTK3_NEW)
+#include <libdbusmenu-gtk/menuitem.h>
+#include <libdbusmenu-gtk/client.h>
+#else
+#include <libdbusmenu-gtk3/menuitem.h>
+#include <libdbusmenu-gtk3/client.h>
+#endif
+
+typedef struct _CDIconData {
+	gchar *cMenuPath;
+	gchar *cBusName;
+	DbusmenuGtkClient *client;
+	GList *menu_items_list;
+} CDIconData;
+#endif
+
 //\___________ structure containing the applet's data, like surfaces, dialogs, results of calculus, etc.
 struct _AppletData {
 	dbusMainObject *pMainObject;
 	const gchar *cProgName;
 	gchar *cBasePath;
-	GList *pAppletList;
-	GtkWidget *pModuleSubMenu;
+	///GtkWidget *pModuleSubMenu;
 	GtkWidget *pModuleMainMenu;
 	dbusApplet *pCurrentMenuDbusApplet;
-	Window xActiveWindow;
+	gint iMenuPosition;
+	GldiWindowActor *pActiveWindow;;
 	CairoDockTask *pGetListTask;
 	GList *pUpdateTasksList;
 	} ;
