@@ -22,6 +22,8 @@
 #define __USE_POSIX
 #include <signal.h>
 
+#include <gdk/gdkkeysyms.h> // needed for 'GDK_Escape'
+
 #include "applet-struct.h"
 #include "applet-calendar.h"
 #include "applet-task-editor.h"
@@ -42,7 +44,7 @@ typedef enum _CDClockTaskColumns
 } CDClockTaskColumns;
 
 
-static gboolean on_delete_task_window (GtkWidget *pWidget, GdkEvent *event, CairoDockModuleInstance *myApplet)
+static gboolean on_delete_task_window (GtkWidget *pWidget, GldiModuleInstance *myApplet)
 {
 	//g_print ("%s ()\n", __func__);
 	/// get day
@@ -58,7 +60,7 @@ static gboolean on_delete_task_window (GtkWidget *pWidget, GdkEvent *event, Cair
 	return FALSE;  // detruit la fenetre.
 }
 
-static GtkListStore *_cd_clock_create_model_for_current_day (guint iDay, guint iMonth, guint iYear, CairoDockModuleInstance *myApplet)
+static GtkListStore *_cd_clock_create_model_for_current_day (guint iDay, guint iMonth, guint iYear, GldiModuleInstance *myApplet)
 {
 	//g_print ("%s (%d/%d/%d)\n", __func__, iDay, iMonth, iYear);
 	//\______________ On cree le modele.
@@ -107,11 +109,10 @@ static GtkListStore *_cd_clock_create_model_for_current_day (guint iDay, guint i
 	return pModel;
 }
 
-static void _cd_clock_add_new_task (GtkMenuItem *pMenuItem, CairoDockModuleInstance *myApplet)
+static void _cd_clock_add_new_task (GtkMenuItem *pMenuItem, GldiModuleInstance *myApplet)
 {
 	//g_print ("%s ()\n", __func__);
 	CDClockTask *pTask = g_new0 (CDClockTask, 1);
-	int iDay, iMonth, iYear;
 	
 	pTask->iDay = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (myData.pTaskWindow), "day"));
 	pTask->iMonth = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (myData.pTaskWindow), "month"));
@@ -132,7 +133,7 @@ static void _cd_clock_add_new_task (GtkMenuItem *pMenuItem, CairoDockModuleInsta
 static void _cd_clock_delete_task (GtkMenuItem *pMenuItem, gpointer *data)
 {
 	cd_debug ("%s ()", __func__);
-	CairoDockModuleInstance *myApplet = data[0];
+	GldiModuleInstance *myApplet = data[0];
 	CDClockTask *pTask = data[1];
 	gboolean bDeleted = myData.pBackend->delete_task (pTask, myApplet);
 	
@@ -147,13 +148,13 @@ static void _cd_clock_delete_task (GtkMenuItem *pMenuItem, gpointer *data)
 		cd_clock_update_calendar_marks (myApplet);
 	}
 }
-static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pButton, CairoDockModuleInstance *myApplet)
+static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pButton, GldiModuleInstance *myApplet)
 {
 	static gpointer *data = NULL;
 	if (pButton->button == 3 && pButton->type == GDK_BUTTON_RELEASE)
 	{
-		GtkWidget *pMenu = gtk_menu_new ();
-		cairo_dock_add_in_menu_with_stock_and_data (D_("Add a new task"), GTK_STOCK_ADD, (GFunc)_cd_clock_add_new_task, pMenu, myApplet);
+		GtkWidget *pMenu = gldi_menu_new (NULL);
+		cairo_dock_add_in_menu_with_stock_and_data (D_("Add a new task"), GTK_STOCK_ADD, G_CALLBACK (_cd_clock_add_new_task), pMenu, myApplet);
 		
 		GtkTreeSelection *pSelection = gtk_tree_view_get_selection (pTreeView);
 		GtkTreeModel *pModel;
@@ -174,7 +175,7 @@ static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pBu
 				data[0] = myApplet;
 				data[1] = pTask;
 				data[2] = pModel;
-				cairo_dock_add_in_menu_with_stock_and_data (D_("Delete this task"), GTK_STOCK_REMOVE, (GFunc)_cd_clock_delete_task, pMenu, data);
+				cairo_dock_add_in_menu_with_stock_and_data (D_("Delete this task"), GTK_STOCK_REMOVE, G_CALLBACK (_cd_clock_delete_task), pMenu, data);
 			}
 		}
 		gtk_widget_show_all (pMenu);
@@ -189,7 +190,7 @@ static gboolean _on_click_tree_view (GtkTreeView *pTreeView, GdkEventButton* pBu
 	return FALSE;
 }
 
-static gboolean _cd_clock_select_one_item_in_tree (GtkTreeSelection * selection, GtkTreeModel * model, GtkTreePath * path, gboolean path_currently_selected, CairoDockModuleInstance *myApplet)
+static gboolean _cd_clock_select_one_item_in_tree (GtkTreeSelection * selection, GtkTreeModel * model, GtkTreePath * path, gboolean path_currently_selected, GldiModuleInstance *myApplet)
 {
 	if (path_currently_selected)
 		return TRUE;
@@ -240,7 +241,7 @@ static GtkListStore *_make_frequency_list_store (void)
 	g_free (cID);\
 	g_return_if_fail (pTask != NULL);
 	
-static void _on_change_title (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_title (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	if (new_text == NULL || *new_text == '\0')\
 		return;
@@ -255,7 +256,7 @@ static void _on_change_title (GtkCellRendererText * cell, gchar * path_string, g
 	}
 }
 
-static void _on_change_text (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_text (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	_get_task_from_path (new_text, path_string);
 	
@@ -268,7 +269,7 @@ static void _on_change_text (GtkCellRendererText * cell, gchar * path_string, gc
 	}
 }
 
-static void _on_change_tags (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_tags (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	_get_task_from_path (new_text, path_string);
 	
@@ -281,7 +282,7 @@ static void _on_change_tags (GtkCellRendererText * cell, gchar * path_string, gc
 	}
 }
 
-static void _on_change_time (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_time (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	_get_task_from_path(new_text, path_string);
 	
@@ -313,7 +314,7 @@ static gboolean _search_frequency (GtkTreeModel * model, GtkTreePath * path, Gtk
 	}
 	return FALSE;
 }
-static void _on_change_frequency (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, CairoDockModuleInstance *myApplet)
+static void _on_change_frequency (GtkCellRendererText * cell, gchar * path_string, gchar * new_text, GldiModuleInstance *myApplet)
 {
 	_get_task_from_path(new_text, path_string);
 	
@@ -335,7 +336,7 @@ static void _on_change_frequency (GtkCellRendererText * cell, gchar * path_strin
 	}
 }
 
-static void _cd_clock_render_frequency (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *model,GtkTreeIter *iter, CairoDockModuleInstance *myApplet)
+static void _cd_clock_render_frequency (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *model,GtkTreeIter *iter, GldiModuleInstance *myApplet)
 {
 	int iFrequency;
 	gtk_tree_model_get (model, iter, CD_TASK_FREQ, &iFrequency, -1);
@@ -355,7 +356,7 @@ static void _cd_clock_render_frequency (GtkTreeViewColumn *tree_column, GtkCellR
 	}
 }
 
-static void _cd_clock_render_time (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *model,GtkTreeIter *iter, CairoDockModuleInstance *myApplet)
+static void _cd_clock_render_time (GtkTreeViewColumn *tree_column, GtkCellRenderer *cell, GtkTreeModel *model,GtkTreeIter *iter, GldiModuleInstance *myApplet)
 {
 	int iTime;
 	gtk_tree_model_get (model, iter, CD_TASK_TIME, &iTime, -1);
@@ -368,7 +369,19 @@ static void _cd_clock_render_time (GtkTreeViewColumn *tree_column, GtkCellRender
 }
 
 
-void cd_clock_build_task_editor (guint iDay, guint iMonth, guint iYear, CairoDockModuleInstance *myApplet)
+gboolean _on_key_press (G_GNUC_UNUSED GtkWidget *pWidget,
+	GdkEventKey *pKey,
+	GldiModuleInstance *myApplet)
+{
+	if (pKey->type == GDK_KEY_PRESS && pKey->keyval == GLDI_KEY(Escape))
+	{
+		gtk_widget_destroy (myData.pTaskWindow);
+		return TRUE;
+	}
+	return FALSE;
+}
+
+void cd_clock_build_task_editor (guint iDay, guint iMonth, guint iYear, GldiModuleInstance *myApplet)
 {
 	//\______________ On remplit le modele avec la date courante.
 	GtkListStore *pModel = _cd_clock_create_model_for_current_day (iDay, iMonth, iYear, myApplet);
@@ -379,6 +392,11 @@ void cd_clock_build_task_editor (guint iDay, guint iMonth, guint iYear, CairoDoc
 		myData.pTaskWindow = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 		gtk_window_set_modal (GTK_WINDOW (myData.pTaskWindow), TRUE);  // set as modal, since the dialog it comes from (the one containing the calendar) is modal (as any interactive dialog).
 		
+		g_signal_connect (G_OBJECT (myData.pTaskWindow),
+			"key-press-event",
+			G_CALLBACK (_on_key_press),
+			myApplet);
+		
 		//\______________ On construit le treeview.
 		GtkWidget *pTreeView = gtk_tree_view_new ();
 		gtk_tree_view_set_model (GTK_TREE_VIEW (pTreeView), GTK_TREE_MODEL (pModel));
@@ -444,11 +462,15 @@ void cd_clock_build_task_editor (guint iDay, guint iMonth, guint iYear, CairoDoc
 		//\______________ On l'ajoute a la fenetre.
 		GtkWidget *pScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (pScrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		#if GTK_CHECK_VERSION (3, 8, 0)
+		gtk_container_add (GTK_CONTAINER (pScrolledWindow), pTreeView);
+		#else
 		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (pScrolledWindow), pTreeView);
+		#endif
 		gtk_container_add (GTK_CONTAINER (myData.pTaskWindow), pScrolledWindow);
 		//gtk_box_pack_start (GTK_BOX (pVBox), pScrolledWindow, FALSE, FALSE, 0);
 		
-		g_signal_connect (myData.pTaskWindow, "delete-event", G_CALLBACK (on_delete_task_window), myApplet);
+		g_signal_connect (myData.pTaskWindow, "destroy", G_CALLBACK (on_delete_task_window), myApplet);
 		gtk_window_set_keep_above (GTK_WINDOW (myData.pTaskWindow), TRUE);
 		///gtk_window_set_modal (GTK_WINDOW (myData.pTaskWindow), TRUE);
 		gtk_window_resize (GTK_WINDOW (myData.pTaskWindow), 640, 300);
