@@ -45,14 +45,14 @@ CD_APPLET_GET_CONFIG_BEGIN
 	myConfig.cCustomScripts[CD_TYPE_VIDEO] = CD_CONFIG_GET_STRING ("Configuration", "video script");
 	myConfig.cCustomScripts[CD_TYPE_FILE] = CD_CONFIG_GET_STRING ("Configuration", "file script");
 	int i;
-	for (i = 0; i < CD_NB_FILE_TYPES; i ++)  // on empeche de choisir le backend custom si aucun script n'est fourni.
+	for (i = 0; i < CD_NB_FILE_TYPES; i ++)  // avoid using custom backend if no script is set for this type
 	{
 		if (myConfig.cCustomScripts[i] == NULL && myConfig.iPreferedSite[i] == 0)
 			myConfig.iPreferedSite[i] = 1;
 	}
-	myConfig.cDropboxDir = CD_CONFIG_GET_STRING ("Configuration", "dropbox dir");
-	if (myConfig.cDropboxDir && myConfig.cDropboxDir[strlen(myConfig.cDropboxDir)-1] == '/')
-		myConfig.cDropboxDir[strlen(myConfig.cDropboxDir)-1] = '\0';
+	myConfig.cLocalDir = CD_CONFIG_GET_STRING ("Configuration", "dropbox dir");
+	if (myConfig.cLocalDir && myConfig.cLocalDir[strlen(myConfig.cLocalDir)-1] == '/')
+		myConfig.cLocalDir[strlen(myConfig.cLocalDir)-1] = '\0';
 	myConfig.bAnonymous = CD_CONFIG_GET_BOOLEAN ("Configuration", "anonymous");
 	myConfig.iTinyURLService = CD_CONFIG_GET_INTEGER_WITH_DEFAULT ("Configuration", "tiny url", 1);
 	if (myConfig.iTinyURLService != 0)
@@ -66,16 +66,13 @@ CD_APPLET_RESET_CONFIG_BEGIN
 	int i;
 	for (i = 0; i < CD_NB_FILE_TYPES; i ++)
 		g_free (myConfig.cCustomScripts[i]);
-	g_free (myConfig.cDropboxDir);
+	g_free (myConfig.cLocalDir);
 CD_APPLET_RESET_CONFIG_END
 
 
 //\_________________ Here you have to free all ressources allocated for myData. This one will be reseted to 0 at the end of this function. This function is called when your applet is stopped, in the very end.
 CD_APPLET_RESET_DATA_BEGIN
-	cairo_dock_free_task (myData.pTask);  // stoppe la tache.
-	
-	g_free (myData.cCurrentFilePath);  // on libere la memoire partagee apres.
-	g_strfreev (myData.cResultUrls);
+	cairo_dock_discard_task (myData.pTask);
 	
 	cd_dnd2share_clear_history ();
 	
