@@ -20,10 +20,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <glib/gi18n.h>
-#include<X11/Xlib.h>
+#include <X11/Xlib.h>
 #ifdef HAVE_XRANDR
-#include<X11/extensions/Xrandr.h>
+#include <X11/extensions/Xrandr.h>
 #endif
+#include <gdk/gdkx.h>
 
 #include "applet-struct.h"
 #include "applet-notifications.h"
@@ -39,10 +40,10 @@ static void _cd_show_hide_desktop (gboolean bShowDesklets)
 {
 	if (! myData.bDesktopVisible && ! bShowDesklets)  // on autorise chaque desklet a etre minimise. l'autorisation est annulee lors de leur cachage, donc on n'a pas besoin de faire le contraire apres avoir montre le bureau.
 	{
-		cairo_dock_foreach_desklet ((CairoDockForeachDeskletFunc) _cd_allow_minimize, NULL);
+		gldi_desklets_foreach ((GldiDeskletForeachFunc) _cd_allow_minimize, NULL);
 	}
 	
-	cairo_dock_show_hide_desktop (! myData.bDesktopVisible);
+	gldi_desktop_show_hide (! myData.bDesktopVisible);
 }
 
 static void _cd_show_hide_desklet (void)
@@ -50,11 +51,11 @@ static void _cd_show_hide_desklet (void)
 	if (!myData.bDeskletsVisible)
 	{
 		//myData.xLastActiveWindow = cairo_dock_get_current_active_window ();
-		cairo_dock_set_all_desklets_visible (TRUE);  // TRUE <=> les desklets de la couche widget aussi.
+		gldi_desklets_set_visible (TRUE);  // TRUE <=> les desklets de la couche widget aussi.
 	}
 	else
 	{
-		cairo_dock_set_desklets_visibility_to_default ();
+		gldi_desklets_set_visibility_to_default ();
 		//cairo_dock_show_xwindow (myData.xLastActiveWindow);
 	}
 	myData.bDeskletsVisible = ! myData.bDeskletsVisible;
@@ -68,35 +69,21 @@ static void _cd_show_hide_desklet (void)
 	}
 }
 
-static void _compiz_dbus_action (const gchar *cCommand)  // taken from the Compiz-Icon applet, thanks ChangFu !
-{
-	if (! cairo_dock_dbus_detect_application ("org.freedesktop.compiz"))
-	{
-		cd_warning  ("Dbus plug-in must be activated in Compiz !");
-		cairo_dock_show_temporary_dialog_with_icon (D_("You need to run Compiz and activate its 'DBus' plug-in."), myIcon, myContainer, 6000, "same icon");
-	}
-	
-	GError *erreur = NULL;
-	gchar *cDbusCommand = g_strdup_printf ("dbus-send --type=method_call --dest=org.freedesktop.compiz /org/freedesktop/compiz/%s org.freedesktop.compiz.activate string:'root' int32:%d", cCommand, cairo_dock_get_root_id ());
-	g_spawn_command_line_async (cDbusCommand, &erreur);
-	if (erreur != NULL)
-	{
-		cd_warning ("ShowDesktop : when trying to send '%s' : %s", cDbusCommand, erreur->message);
-		g_error_free (erreur);
-	}
-	g_free (cDbusCommand);
-}
 
 static void _cd_show_widget_layer (void)
 {
-	_compiz_dbus_action ("widget/allscreens/toggle_button");  // toggle avant la 0.7
+	gldi_desktop_show_widget_layer ();
 }
 
 static void _cd_expose (void)
 {
-	_compiz_dbus_action ("expo/allscreens/expo_button");  // expo avant la 0.7
+	gldi_desktop_present_desktops ();
+}
+static gboolean _expose_delayed (G_GNUC_UNUSED gpointer data)
+{
+	_cd_expose ();
+	return FALSE;
 }
-
 static void _cd_action (CDActionOnClick iAction)
 {
 	switch (iAction)
@@ -111,10 +98,24 @@ static void _cd_action (CDActionOnClick iAction)
 			_cd_show_hide_desktop (TRUE);  // TRUE <=> show the desklets
 		break ;
 		case CD_SHOW_WIDGET_LAYER :
-			_cd_show_widget_layer ();
+			if (gldi_desktop_can_show_widget_layer ())
+				_cd_show_widget_layer ();
+			else
+			{
+				cd_warning ("It seems there is no widget layer, we show/hide the desktop");
+				_cd_show_hide_desktop (FALSE);
+			}
 		break ;
 		case CD_EXPOSE :
-			_cd_expose ();
+			if (gldi_desktop_can_present_desktops ())
+			{
+				g_timeout_add (250, _expose_delayed, NULL);  // Gnome-Shell bug here: it doesn't execute the Dbus command right after a click; I suspect the delay to be the interval of a double-click... anyway, it's stupid but it's barely noticeable, so it doesn't hurt that much even when not using GS.
+			}
+			else
+			{
+				cd_warning ("It seems we can't present desktops, we show/hide the desktop");
+				_cd_show_hide_desktop (FALSE);
+			}
 		break ;
 		default:
 		break;
@@ -162,86 +163,93 @@ static void _show_desktop (GtkMenuItem *menu_item, gpointer data)
 	_cd_show_hide_desktop (FALSE);
 }
 CD_APPLET_ON_BUILD_MENU_BEGIN
-	GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-	
 	gchar *cLabel;
+	
 	if (myConfig.iActionOnLeftClick != CD_SHOW_DESKTOP)  // action is not bound to left-click => put it in the menu
 	{
 		if (myConfig.iActionOnMiddleClick == CD_SHOW_DESKTOP)
-			cLabel = g_strdup_printf ("%s (%s)", D_("Show the desktop"), D_("middle-click"));
+			cLabel = g_strdup_printf ("%s (%s)", D_("Show desktop"), D_("middle-click"));
 		else
-			cLabel = g_strdup (D_("Show the desktop"));
-		CD_APPLET_ADD_IN_MENU (cLabel, _show_desktop, CD_APPLET_MY_MENU);
+			cLabel = g_strdup (D_("Show desktop"));
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel,
+			MY_APPLET_SHARE_DATA_DIR"/../shared-files/images/show-desktop.svg",
+			_show_desktop,
+			CD_APPLET_MY_MENU);
 		g_free (cLabel);
 	}
-	if (myConfig.iActionOnLeftClick != CD_EXPOSE)  // action is not bound to left-click => put it in the menu
+	if (myConfig.iActionOnLeftClick != CD_EXPOSE && gldi_desktop_can_present_desktops ())  // action is not bound to left-click => put it in the menu
 	{
 		if (myConfig.iActionOnMiddleClick == CD_EXPOSE)
-			cLabel = g_strdup_printf ("%s (%s)", D_("Expose all the desktops (Compiz)"), D_("middle-click"));
+			cLabel = g_strdup_printf ("%s (%s)", D_("Expose all the desktops"), D_("middle-click"));
 		else
-			cLabel = g_strdup (D_("Expose all the desktops (Compiz)"));
-		CD_APPLET_ADD_IN_MENU (cLabel, _cd_expose, CD_APPLET_MY_MENU);
+			cLabel = g_strdup (D_("Expose all the desktops"));
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel,
+			MY_APPLET_SHARE_DATA_DIR"/../shared-files/images/expose-desktops.svg",
+			_cd_expose,
+			CD_APPLET_MY_MENU);
 		g_free (cLabel);
 	}
-	if (myConfig.iActionOnLeftClick != CD_SHOW_WIDGET_LAYER)  // action is not bound to left-click => put it in the menu
+	if (myConfig.iActionOnLeftClick != CD_SHOW_WIDGET_LAYER && gldi_desktop_can_show_widget_layer ())  // action is not bound to left-click => put it in the menu
 	{
 		if (myConfig.iActionOnMiddleClick == CD_SHOW_WIDGET_LAYER)
-			cLabel = g_strdup_printf ("%s (%s)", D_("Show the Widget Layer (Compiz)"), D_("middle-click"));
+			cLabel = g_strdup_printf ("%s (%s)", D_("Show the Widget Layer"), D_("middle-click"));
 		else
-			cLabel = g_strdup (D_("Show the Widget Layer (Compiz)"));
-		CD_APPLET_ADD_IN_MENU (cLabel, _cd_show_widget_layer, CD_APPLET_MY_MENU);
+			cLabel = g_strdup (D_("Show the Widget Layer"));
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel,
+			MY_APPLET_SHARE_DATA_DIR"/../shared-files/images/widget-layer.svg",
+		_cd_show_widget_layer,
+		CD_APPLET_MY_MENU);
 		g_free (cLabel);
 	}  // on ne met pas les actions sur les desklets, surement assez peu utilisees.
 	
 	// Main Menu
 	#ifdef HAVE_XRANDR
-	GtkWidget *pResSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Change screen resolution"), CD_APPLET_MY_MENU, GTK_STOCK_FULLSCREEN);
-	
-	Display                 *dpy;
-	Window                  root;
-	int                     num_sizes;
-	XRRScreenSize           *xrrs;
-	XRRScreenConfiguration  *conf;
-	short                   original_rate;
-	Rotation                original_rotation;
-	SizeID                  original_size_id;
-	
-	dpy = gdk_x11_get_default_xdisplay ();
-	root = RootWindow(dpy, 0);
-	
-	conf = XRRGetScreenInfo(dpy, root);  // config  courante.
-	if (conf != NULL)
+	if (cairo_dock_check_xrandr (1, 1))
 	{
-		original_rate = XRRConfigCurrentRate(conf);
-		original_size_id = XRRConfigCurrentConfiguration(conf, &original_rotation);
+		GtkWidget *pResSubMenu = CD_APPLET_ADD_SUB_MENU_WITH_IMAGE (D_("Change screen resolution"), CD_APPLET_MY_MENU, GTK_STOCK_FULLSCREEN);
 		
-		// resolutions possibles.
-		int num_sizes = 0;
-		XRRScreenSize *xrrs = XRRSizes(dpy, 0, &num_sizes);
-		// add to the menu
-		GString *pResString = g_string_new ("");
-		int i;
-		for (i = 0; i < num_sizes; i ++)
+		Display                 *dpy;
+		Window                  root;
+		XRRScreenConfiguration  *conf;
+		Rotation                original_rotation;
+		SizeID                  original_size_id;
+		
+		dpy = gdk_x11_get_default_xdisplay ();
+		root = RootWindow(dpy, 0);
+		
+		conf = XRRGetScreenInfo(dpy, root);  // config  courante.
+		if (conf != NULL)
 		{
-			g_string_printf (pResString, "%dx%d", xrrs[i].width, xrrs[i].height);
-			if (i == original_size_id)
-				CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (pResString->str, GTK_STOCK_APPLY, _on_select_resolution, pResSubMenu, GINT_TO_POINTER (i));
-			else
-				CD_APPLET_ADD_IN_MENU_WITH_DATA (pResString->str, _on_select_resolution, pResSubMenu, GINT_TO_POINTER (i));
-			/*short   *rates;
-			int     num_rates;
-			rates = XRRRates(dpy, 0, i, &num_rates);
-			for(int j = 0; j < num_rates; j ++) {
-				possible_frequencies[i][j] = rates[j];
-				printf("%4i ", rates[j]); }*/
+			//original_rate = XRRConfigCurrentRate(conf);
+			original_size_id = XRRConfigCurrentConfiguration(conf, &original_rotation);
+			
+			// resolutions possibles.
+			int num_sizes = 0;
+			XRRScreenSize *xrrs = XRRSizes(dpy, 0, &num_sizes);
+			// add to the menu
+			GString *pResString = g_string_new ("");
+			int i;
+			for (i = 0; i < num_sizes; i ++)
+			{
+				g_string_printf (pResString, "%dx%d", xrrs[i].width, xrrs[i].height);
+				if (i == original_size_id)
+					CD_APPLET_ADD_IN_MENU_WITH_STOCK_AND_DATA (pResString->str, GTK_STOCK_APPLY, _on_select_resolution, pResSubMenu, GINT_TO_POINTER (i));
+				else
+					CD_APPLET_ADD_IN_MENU_WITH_DATA (pResString->str, _on_select_resolution, pResSubMenu, GINT_TO_POINTER (i));
+				/*short   *rates;
+				int     num_rates;
+				rates = XRRRates(dpy, 0, i, &num_rates);
+				for(int j = 0; j < num_rates; j ++) {
+					possible_frequencies[i][j] = rates[j];
+					printf("%4i ", rates[j]); }*/
+			}
+			g_string_free (pResString, TRUE);
+			XRRFreeScreenConfigInfo (conf);
 		}
-		g_string_free (pResString, TRUE);
-		XRRFreeScreenConfigInfo (conf);
 	}
+	else
+		cd_warning ("Xrandr extension not available.");
 	#endif
-	
-	//Sub-Menu
-	CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
 CD_APPLET_ON_BUILD_MENU_END
 
 
@@ -257,7 +265,7 @@ static gchar *_get_desktop_path (void)
 		cDesktopDir = g_strdup_printf ("%s/Desktop", g_getenv ("HOME"));
 	return cDesktopDir;
 }
-static void _move_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+static void _move_to_desktop (GtkMenuItem *menu_item, GldiModuleInstance *myApplet)
 {
 	gchar *cDesktopDir = _get_desktop_path ();
 	if (cDesktopDir != NULL)
@@ -266,7 +274,7 @@ static void _move_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstance *m
 		g_free (cDesktopDir);
 	}
 }
-static void _copy_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+static void _copy_to_desktop (GtkMenuItem *menu_item, GldiModuleInstance *myApplet)
 {
 	gchar *cDesktopDir = _get_desktop_path ();
 	if (cDesktopDir != NULL)
@@ -275,7 +283,7 @@ static void _copy_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstance *m
 		g_free (cDesktopDir);
 	}
 }
-static void _link_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+static void _link_to_desktop (GtkMenuItem *menu_item, GldiModuleInstance *myApplet)
 {
 	gchar *cDesktopDir = _get_desktop_path ();
 	if (cDesktopDir != NULL)
@@ -284,7 +292,7 @@ static void _link_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstance *m
 		g_free (cDesktopDir);
 	}
 }
-static void _make_link_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+static void _make_link_to_desktop (GtkMenuItem *menu_item, GldiModuleInstance *myApplet)
 {
 	gchar *cDesktopDir = _get_desktop_path ();
 	if (cDesktopDir != NULL)
@@ -312,37 +320,33 @@ static void _make_link_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstan
 }
 static void _dl_finished (gpointer data)
 {
-	g_print ("DL IS FINISHED\n");
+	cd_debug ("DL IS FINISHED");
 }
-static void _download_to_desktop (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
+static void _download_to_desktop (GtkMenuItem *menu_item, GldiModuleInstance *myApplet)
 {
 	gchar *cDesktopDir = _get_desktop_path ();
 	if (cDesktopDir != NULL)
 	{
-		
-		CairoDockTask *pTask = cairo_dock_download_file_async (NULL, NULL, myData.cPendingFile, NULL, (GFunc)_dl_finished, myApplet);
-		
-		
-		
+		cairo_dock_download_file_async (myData.cPendingFile, NULL, (GFunc)_dl_finished, myApplet);
 		g_free (cDesktopDir);
 	}
 }
 
 CD_APPLET_ON_DROP_DATA_BEGIN
-	GtkWidget *pMenu = gtk_menu_new ();
+	GtkWidget *pMenu = gldi_menu_new (myIcon);
 	g_free (myData.cPendingFile);
 	myData.cPendingFile = g_strdup (CD_APPLET_RECEIVED_DATA);
 	
 	if (*CD_APPLET_RECEIVED_DATA == '/' || strncmp (CD_APPLET_RECEIVED_DATA, "file://", 7))  // fichier local
 	{
-		cairo_dock_add_in_menu_with_stock_and_data (D_("Move to the Desktop"), GTK_STOCK_CUT, (GFunc) _move_to_desktop, pMenu, myApplet);
-		cairo_dock_add_in_menu_with_stock_and_data (D_("Copy to the Desktop"), GTK_STOCK_COPY, (GFunc) _copy_to_desktop, pMenu, myApplet);
-		cairo_dock_add_in_menu_with_stock_and_data (D_("Link to the Desktop"), GTK_STOCK_JUMP_TO, (GFunc) _link_to_desktop, pMenu, myApplet);
+		cairo_dock_add_in_menu_with_stock_and_data (("Move to the Desktop"), GTK_STOCK_CUT, G_CALLBACK (_move_to_desktop), pMenu, myApplet);
+		cairo_dock_add_in_menu_with_stock_and_data (("Copy to the Desktop"), GTK_STOCK_COPY, G_CALLBACK (_copy_to_desktop), pMenu, myApplet);
+		cairo_dock_add_in_menu_with_stock_and_data (("Link to the Desktop"), GTK_STOCK_JUMP_TO, G_CALLBACK (_link_to_desktop), pMenu, myApplet);
 	}
 	else  // fichier a telecharger.
 	{
-		cairo_dock_add_in_menu_with_stock_and_data (D_("Link to the Desktop"), GTK_STOCK_JUMP_TO, (GFunc) _make_link_to_desktop, pMenu, myApplet);
-		cairo_dock_add_in_menu_with_stock_and_data (D_("Download onto the Desktop"), GTK_STOCK_COPY, (GFunc) _download_to_desktop, pMenu, myApplet);
+		cairo_dock_add_in_menu_with_stock_and_data (("Link to the Desktop"), GTK_STOCK_JUMP_TO, G_CALLBACK (_make_link_to_desktop), pMenu, myApplet);
+		cairo_dock_add_in_menu_with_stock_and_data (("Download onto the Desktop"), GTK_STOCK_COPY, G_CALLBACK (_download_to_desktop), pMenu, myApplet);
 	}
 	CD_APPLET_POPUP_MENU_ON_MY_ICON (pMenu);
 	
@@ -358,11 +362,11 @@ void on_keybinding_pull (const char *keystring, gpointer user_data)
 }
 
 
-gboolean on_show_desktop (CairoDockModuleInstance *myApplet)
+gboolean on_show_desktop (GldiModuleInstance *myApplet)
 {
 	CD_APPLET_ENTER;
-	myData.bDesktopVisible = cairo_dock_desktop_is_visible ();
-	cd_debug ("bDesktopVisible <- %d\n", myData.bDesktopVisible);
+	myData.bDesktopVisible = gldi_desktop_is_visible ();
+	cd_debug ("bDesktopVisible <- %d", myData.bDesktopVisible);
 	
 	if (myConfig.cVisibleImage)
 	{
@@ -372,5 +376,5 @@ gboolean on_show_desktop (CairoDockModuleInstance *myApplet)
 			CD_APPLET_SET_IMAGE_ON_MY_ICON (myConfig.cHiddenImage);
 		CD_APPLET_REDRAW_MY_ICON;
 	}
-	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);
 }
