@@ -29,6 +29,7 @@
 #include <gdk/gdkkeysyms.h>
 // gdk.h semble necessaire pour certains
 #include <gdk/gdk.h>
+//#include <gdk/gdkx.h>
 
 #include <vte/vte.h>
 
@@ -37,6 +38,10 @@
 #include "terminal-menu-functions.h"
 #include "terminal-widget.h"
 
+#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION > 20)
+#include <gdk/gdkkeysyms-compat.h>
+#endif
+
 void cd_terminal_grab_focus (void)
 {
 	int iCurrentNumPage = gtk_notebook_get_current_page (GTK_NOTEBOOK(myData.tab));
@@ -46,11 +51,14 @@ void cd_terminal_grab_focus (void)
 
 CairoDialog *cd_terminal_build_dialog (void)
 {
-	CairoDialogAttribute attr;
-	memset (&attr, 0, sizeof (CairoDialogAttribute));
-	attr.cText = D_ ("Terminal");
+	CairoDialogAttr attr;
+	memset (&attr, 0, sizeof (CairoDialogAttr));
+	attr.cText = D_("Terminal");
 	attr.pInteractiveWidget = myData.tab;
-	return cairo_dock_build_dialog (&attr, myIcon, myContainer);
+	attr.bHideOnClick = TRUE;  // keep the dialog alive on click (hide it).
+	attr.pIcon = myIcon;
+	attr.pContainer = myContainer;
+	return gldi_dialog_new (&attr);
 }
 
 void term_on_keybinding_pull(const char *keystring, gpointer user_data)
@@ -59,39 +67,26 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 	{
 		if (myDesklet)
 		{
-			gboolean bHasFocus = (gtk_window_has_toplevel_focus (GTK_WINDOW (myDesklet->container.pWidget)) || GTK_WIDGET_HAS_FOCUS (myData.tab) || GTK_WIDGET_HAS_FOCUS (myDesklet->container.pWidget));
-			if (! bHasFocus)
-			{
-				GtkWidget *vterm;
-				int i, iNbPages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (myData.tab));
-				for (i = 0; i < iNbPages && ! bHasFocus; ++i)
-				{
-					vterm = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), i);
-					bHasFocus = GTK_WIDGET_HAS_FOCUS (vterm);
-				}
-				bHasFocus |= (GDK_WINDOW_XID (myDesklet->container.pWidget->window) == cairo_dock_get_current_active_window ());
-			}
-			cd_debug ("%s (%d)\n", __func__, bHasFocus);
-			
+			gboolean bHasFocus = gldi_container_is_active (myContainer);
 			if (bHasFocus)
 			{
-				cairo_dock_hide_desklet(myDesklet);
+				gldi_desklet_hide (myDesklet);
 			}
 			else
 			{
-				cairo_dock_show_desklet (myDesklet);
-				
+				gldi_desklet_show (myDesklet);
+				cd_terminal_grab_focus ();
 			}
 		}
 		else if (myData.dialog)
 		{
-			if (GTK_WIDGET_VISIBLE (myData.dialog->container.pWidget))
+			if (gldi_container_is_visible (CAIRO_CONTAINER (myData.dialog)))
 			{
-				cairo_dock_hide_dialog (myData.dialog);
+				gldi_dialog_hide (myData.dialog);
 			}
 			else
 			{
-				cairo_dock_unhide_dialog (myData.dialog);
+				gldi_dialog_unhide (myData.dialog);
 				cd_terminal_grab_focus ();
 			}
 		}
@@ -102,12 +97,14 @@ void term_on_keybinding_pull(const char *keystring, gpointer user_data)
 	}
 }
 
-
+#if GTK_CHECK_VERSION (3, 4, 0)
+static gchar *_get_label_and_color (const gchar *cLabel, GdkRGBA *pColor, gboolean *bColorSet)
+#else
 static gchar *_get_label_and_color (const gchar *cLabel, GdkColor *pColor, gboolean *bColorSet)
+#endif
 {
 	gchar *cUsefulLabel;
 	gchar *str = strchr (cLabel, '>');
-	//g_print ("%s (%s)\n", __func__, cLabel);
 	if (cLabel != NULL && strncmp (cLabel, "<span color='", 13) == 0 && str != NULL)  // approximatif mais devrait suffire.
 	{
 		const gchar *col = cLabel+13;
@@ -115,8 +112,11 @@ static gchar *_get_label_and_color (const gchar *cLabel, GdkColor *pColor, gbool
 		if (col_end)
 		{
 			gchar *cColor = g_strndup (col, col_end - col);
-			//g_print ("cColor : %s\n", cColor);
+			#if GTK_CHECK_VERSION (3, 4, 0)
+			*bColorSet = gdk_rgba_parse (pColor, cColor);
+			#else
 			*bColorSet = gdk_color_parse (cColor, pColor);
+			#endif
 			g_free (cColor);
 		}
 		cUsefulLabel = g_strdup (str+1);
@@ -131,6 +131,46 @@ static gchar *_get_label_and_color (const gchar *cLabel, GdkColor *pColor, gbool
 	return cUsefulLabel;
 }
 
+static void _on_got_tab_name (int iClickedButton, GtkWidget *pInteractiveWidget, gpointer *data, CairoDialog *pDialog)
+{
+	CD_APPLET_ENTER;
+	
+	if (iClickedButton == 0 || iClickedButton == -1)  // ok button or Enter.
+	{
+		const gchar *cNewName = gtk_entry_get_text (GTK_ENTRY (pInteractiveWidget));
+		if (cNewName != NULL)
+		{
+			GtkLabel *pLabel = data[0];
+			#if GTK_CHECK_VERSION (3, 4, 0)
+			GdkRGBA *pColor = data[1];
+			#else
+			GdkColor *pColor = data[1];
+			#endif
+			if (pColor)
+			{
+				#if GTK_CHECK_VERSION (3, 4, 0)
+				gchar *cColor = gdk_rgba_to_string (pColor);
+				#else
+				gchar *cColor = gdk_color_to_string (pColor);
+				#endif
+				gchar *cNewColoredName = g_strdup_printf ("<span color='%s'>%s</span>", cColor, cNewName);
+				gtk_label_set_markup (pLabel, cNewColoredName);
+				g_free (cNewColoredName);
+				g_free (cColor);
+			}
+			else
+			{
+				gtk_label_set_text (pLabel, cNewName);
+			}
+		}
+	}
+	CD_APPLET_LEAVE ();
+}
+static void _free_rename_data (gpointer *data)
+{
+	g_free (data[1]);
+	g_free (data);
+}
 void terminal_rename_tab (GtkWidget *vterm)
 {
 	cd_message ("");
@@ -141,45 +181,59 @@ void terminal_rename_tab (GtkWidget *vterm)
 	}
 	GtkWidget *pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), vterm);
 	GList *pTabWidgetList = gtk_container_get_children (GTK_CONTAINER (pTabLabelWidget));
-	GtkLabel *pLabel;
-	const gchar *cCurrentName;
 	if (pTabWidgetList != NULL && pTabWidgetList->data != NULL)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
 		const gchar *cCurrentName = gtk_label_get_label (pLabel);
-		GdkColor color;
+		#if GTK_CHECK_VERSION (3, 4, 0)
+		GdkRGBA *pColor = g_new0 (GdkRGBA, 1);
+		#else
+		GdkColor *pColor = g_new0 (GdkColor, 1);
+		#endif
 		gboolean bColorSet = FALSE;
-		gchar *cUsefulLabel = _get_label_and_color (cCurrentName, &color, &bColorSet);
-		
-		gchar *cNewName = cairo_dock_show_demand_and_wait (D_("Set title for this tab:"), NULL, (myDock ? CAIRO_CONTAINER (myData.dialog) : CAIRO_CONTAINER (myDesklet)), cUsefulLabel);
-		g_free (cUsefulLabel);
-		
-		if (cNewName != NULL)
+		gchar *cUsefulLabel = _get_label_and_color (cCurrentName, pColor, &bColorSet);
+		if (!bColorSet)
 		{
-			if (bColorSet)
-			{
-				gchar *cColor = gdk_color_to_string (&color);
-				gchar *cNewColoredName = g_strdup_printf ("<span color='%s'>%s</span>", cColor, cNewName);
-				gtk_label_set_markup (pLabel, cNewColoredName);
-				g_free (cNewColoredName);
-				g_free (cColor);
-			}
-			else
-			{
-				gtk_label_set_text (pLabel, cNewName);
-			}
-			g_free (cNewName);
+			g_free (pColor);
+			pColor = NULL;
 		}
+		
+		gpointer *data = g_new (gpointer, 2);
+		data[0] = pLabel;
+		data[1] = pColor;
+		gldi_dialog_show_with_entry (D_("Set title for this tab:"),
+			myIcon, myContainer, "same icon",  /// NULL, (myDock ? CAIRO_CONTAINER (myData.dialog) : CAIRO_CONTAINER (myDesklet))
+			cUsefulLabel,
+			(CairoDockActionOnAnswerFunc)_on_got_tab_name, data, (GFreeFunc)_free_rename_data);
+		g_free (cUsefulLabel);
 		g_list_free (pTabWidgetList);
 	}
 }
 
+#if GTK_CHECK_VERSION (3, 4, 0) // now we have a GtkColorChooserDialog which impliments GtkColorChooser
+static void _set_color (GtkDialog *pColorSelection, gint iAnswer, GtkLabel *pLabel)
+{
+	if (iAnswer != GTK_RESPONSE_OK)
+		return gtk_widget_destroy (GTK_WIDGET (pColorSelection));
+
+	GdkRGBA color;
+	gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (pColorSelection), &color);
+	gtk_widget_destroy (GTK_WIDGET (pColorSelection)); // we can close the dialog.
+
+	/* 'gdk_rgba_to_string' returns a string like that: 'rgb(r, g, b)'
+	 * but it's not supported by span's color specification...
+	 */
+	gchar *cColor = g_strdup_printf ("#%X%X%X",
+		(guint) (color.red * 65535),
+		(guint) (color.green * 65535),
+		(guint) (color.blue * 65535));
+#else
 static void _set_color (GtkColorSelection *pColorSelection, GtkLabel *pLabel)
 {
 	GdkColor color;
 	gtk_color_selection_get_current_color (pColorSelection, &color);
-	
 	gchar *cColor = gdk_color_to_string (&color);
+#endif
 	
 	const gchar *cCurrentLabel = gtk_label_get_text (pLabel);  // recupere le texte sans les balises pango.
 	//gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, NULL, NULL);
@@ -200,28 +254,47 @@ void terminal_change_color_tab (GtkWidget *vterm)
 	}
 	GtkWidget *pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), vterm);
 	GList *pTabWidgetList = gtk_container_get_children (GTK_CONTAINER (pTabLabelWidget));
-	GtkLabel *pLabel;
-	const gchar *cCurrentName = NULL;
 	if (pTabWidgetList != NULL && pTabWidgetList->data != NULL)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
 		
+		#if GTK_CHECK_VERSION (3, 4, 0)
+		GtkWidget *pColorDialog = gtk_color_chooser_dialog_new (D_("Select a color"), NULL);
+		#else
 		GtkWidget *pColorDialog = gtk_color_selection_dialog_new (D_("Select a color"));
-		
+		GtkWidget *colorsel = gtk_color_selection_dialog_get_color_selection ((GtkColorSelectionDialog *) pColorDialog);
+		#endif
+
 		const gchar *cCurrentLabel = gtk_label_get_text (pLabel);
+		#if GTK_CHECK_VERSION (3, 4, 0)
+		GdkRGBA color;
+		#else
 		GdkColor color;
+		#endif
 		gboolean bColorSet = FALSE;
 		gchar *cUsefulLabel = _get_label_and_color (cCurrentLabel, &color, &bColorSet);
+		g_free (cUsefulLabel);
 		if (bColorSet)
 		{
-			gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (((GtkColorSelectionDialog *) pColorDialog)->colorsel), &color);
+			#if GTK_CHECK_VERSION (3, 4, 0)
+			gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (pColorDialog), &color);
+			#else
+			gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (colorsel), &color);
+			#endif
 		}
-		
-		gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (((GtkColorSelectionDialog *) pColorDialog)->colorsel), FALSE);
-		g_signal_connect (((GtkColorSelectionDialog *) pColorDialog)->colorsel, "color-changed", GTK_SIGNAL_FUNC (_set_color), pLabel);
+
+		#if GTK_CHECK_VERSION (3, 4, 0)
+		gtk_color_chooser_set_use_alpha (GTK_COLOR_CHOOSER (pColorDialog), FALSE);
+		g_signal_connect (pColorDialog, "response", G_CALLBACK (_set_color), pLabel);
+		#else
+		gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (colorsel), FALSE);
+		g_signal_connect (colorsel, "color-changed", G_CALLBACK (_set_color), pLabel);
+		#endif
+		#if (GTK_MAJOR_VERSION < 3)
 		gtk_widget_hide (((GtkColorSelectionDialog *) pColorDialog)->cancel_button);
 		gtk_widget_hide (((GtkColorSelectionDialog *) pColorDialog)->help_button);
-		g_signal_connect_swapped (((GtkColorSelectionDialog *) pColorDialog)->ok_button, "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy), pColorDialog);
+		g_signal_connect_swapped (((GtkColorSelectionDialog *) pColorDialog)->ok_button, "clicked", G_CALLBACK (gtk_widget_destroy), pColorDialog);
+		#endif
 		
 		gtk_window_present (GTK_WINDOW (pColorDialog));
 	}
@@ -247,30 +320,43 @@ void terminal_close_tab (GtkWidget *vterm)
 
 static void _term_apply_settings_on_vterm(GtkWidget *vterm)
 {
-  g_return_if_fail (vterm != NULL);
-  vte_terminal_set_colors(VTE_TERMINAL(vterm), &myConfig.forecolor, &myConfig.backcolor, NULL, 0);
-      //vte_terminal_set_background_saturation(VTE_TERMINAL(vterm), 1.0);
-      //vte_terminal_set_background_transparent(VTE_TERMINAL(vterm), TRUE);
-#if GTK_MINOR_VERSION >= 12
-  vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
-#endif
-  
+	g_return_if_fail (vterm != NULL);
+	vte_terminal_set_colors(VTE_TERMINAL(vterm), &myConfig.forecolor, &myConfig.backcolor, NULL, 0);
+	#if (GTK_MAJOR_VERSION > 2 || GTK_MINOR_VERSION >= 12)
+	vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
+	#endif
+
+	if (myConfig.bCustomFont)
+		vte_terminal_set_font_from_string (VTE_TERMINAL (vterm), myConfig.cCustomFont);
+	else
+		vte_terminal_set_font (VTE_TERMINAL (vterm), NULL);
+
+	vte_terminal_set_scroll_on_output (VTE_TERMINAL (vterm), myConfig.bScrollOutput);
+	vte_terminal_set_scroll_on_keystroke (VTE_TERMINAL (vterm), myConfig.bScrollKeystroke);
+	if (myConfig.bScrollback)
+		vte_terminal_set_scrollback_lines (VTE_TERMINAL (vterm), myConfig.iScrollback);
+	else
+		vte_terminal_set_scrollback_lines (VTE_TERMINAL (vterm), -1); // -1 <=> infinite
+
 	if (myDock)
 	{
-		//g_print ("set_size (%d , %d)\n", myConfig.iNbColumns, myConfig.iNbRows);
-		gtk_widget_set (vterm, "width-request", 0, NULL);
-		gtk_widget_set (vterm, "height-request", 0, NULL);
+		// since dialogs can't be resized (like desklets), set the size as defined in the config.
+		// Note: vte_terminal_set_size() doesn't work since the port to GTK3.
+		#ifdef LIBVTE_IS_NOT_BUGGY
+		g_object_set (vterm, "width-request", 0, NULL);  // reset if ever it was previously set (removing this line doesn't make vte_terminal_set_size() work ...)
+		g_object_set (vterm, "height-request", 0, NULL);
 		vte_terminal_set_size(VTE_TERMINAL(vterm), myConfig.iNbColumns, myConfig.iNbRows);
-		GtkRequisition requisition = {0, 0};
-		gtk_widget_size_request (vterm, &requisition);
-		//g_print (" -> %dx%d\n", requisition.width, requisition.height);
-		if (myData.dialog)
-			gtk_window_resize (GTK_WINDOW (myData.dialog->container.pWidget), requisition.width, requisition.height);
+		#else
+		g_object_set (vterm,
+			"width-request", myConfig.iNbColumns * vte_terminal_get_char_width (VTE_TERMINAL(vterm)),
+			"height-request", myConfig.iNbRows * vte_terminal_get_char_height (VTE_TERMINAL(vterm)),
+			NULL);
+		#endif
 	}
 	else
 	{
-		gtk_widget_set (vterm, "width-request", 64, NULL);
-		gtk_widget_set (vterm, "height-request", 64, NULL);
+		g_object_set (vterm, "width-request", 64, NULL);
+		g_object_set (vterm, "height-request", 64, NULL);
 	}
 }
 
@@ -304,10 +390,11 @@ static void on_terminal_child_exited(VteTerminal *vterm,
 		pid_t pid; 
 		#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
 			#if VTE_CHECK_VERSION(0,26,0)
+			const gchar *argv[] = {g_getenv ("SHELL"), NULL};
 			vte_terminal_fork_command_full (VTE_TERMINAL(vterm),
 				VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
 				"~/",
-				NULL,  // argv
+				(gchar**)argv,  // argv
 				NULL,  // envv
 				0,  // GSpawnFlags spawn_flags
 				NULL,  // GSpawnChildSetupFunc child_setup
@@ -335,13 +422,13 @@ static void on_terminal_child_exited(VteTerminal *vterm,
 				FALSE);
 		#endif
 		if (myData.dialog)
-			cairo_dock_hide_dialog (myData.dialog);
+			gldi_dialog_hide (myData.dialog);
 		else if (myDesklet && myConfig.shortcut)
 		{
-			cairo_dock_hide_desklet (myDesklet);
-			Icon *icon = cairo_dock_get_dialogless_icon ();
+			gldi_desklet_hide (myDesklet);
+			Icon *icon = gldi_icons_get_any_without_dialog ();
 			g_return_if_fail (icon != NULL);
-			cairo_dock_show_temporary_dialog_with_icon_printf (D_("You can recall the Terminal desklet by typing %s"), icon, CAIRO_CONTAINER (g_pMainDock), 3500, MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE, myConfig.shortcut);
+			gldi_dialog_show_temporary_with_icon_printf (D_("You can recall the Terminal desklet by typing %s"), icon, CAIRO_CONTAINER (g_pMainDock), 3500, MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE, myConfig.shortcut);
 		}
 	}
 }
@@ -356,9 +443,7 @@ static void _terminal_paste (GtkMenuItem *menu_item, GtkWidget *data)
   vte_terminal_paste_clipboard(VTE_TERMINAL(data));
 }
 
-
-
-static void on_new_tab (GtkMenuItem *menu_item, gpointer *data)
+static void on_new_tab (GtkMenuItem *menu_item, G_GNUC_UNUSED gpointer data)
 {
 	terminal_new_tab();
 }
@@ -376,57 +461,32 @@ static void on_close_tab (GtkMenuItem *menu_item, GtkWidget *vterm)
 }
 static GtkWidget *_terminal_build_menu_tab (GtkWidget *vterm)
 {
-	GtkWidget *menu = gtk_menu_new ();
+	GtkWidget *menu = gldi_menu_new (NULL);
 	
-	GtkWidget *menu_item, *image;
+	GtkWidget *menu_item;
 	if (vterm)
 	{
-		menu_item = gtk_image_menu_item_new_with_label (D_("Copy"));
-		image = gtk_image_new_from_stock (GTK_STOCK_COPY, GTK_ICON_SIZE_MENU);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(_terminal_copy), vterm);
+		gldi_menu_add_item (menu, D_("Copy"), GTK_STOCK_COPY, G_CALLBACK(_terminal_copy), vterm);
 		
-		menu_item = gtk_image_menu_item_new_with_label (D_("Paste"));
-		image = gtk_image_new_from_stock (GTK_STOCK_PASTE, GTK_ICON_SIZE_MENU);
-		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-		g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(_terminal_paste), vterm);
+		gldi_menu_add_item (menu, D_("Paste"), GTK_STOCK_PASTE, G_CALLBACK(_terminal_paste), vterm);
 		
 		menu_item = gtk_separator_menu_item_new ();
-		gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
 	}
-
-  menu_item = gtk_image_menu_item_new_with_label (D_("New Tab"));
-  image = gtk_image_new_from_stock (GTK_STOCK_NEW, GTK_ICON_SIZE_MENU);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-  gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-  g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_new_tab), vterm);
-  
-  menu_item = gtk_image_menu_item_new_with_label (D_("Rename this Tab"));
-  image = gtk_image_new_from_stock (GTK_STOCK_EDIT, GTK_ICON_SIZE_MENU);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-  gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-  g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_rename_tab), vterm);
-
-  menu_item = gtk_image_menu_item_new_with_label (D_("Change this Tab's colour"));
-  image = gtk_image_new_from_stock (GTK_STOCK_COLOR_PICKER, GTK_ICON_SIZE_MENU);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-  gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-  g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_change_tab_color), vterm);
-
-  menu_item = gtk_image_menu_item_new_with_label (D_("Close this Tab"));
-  image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
-  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), image);
-  gtk_menu_shell_append  (GTK_MENU_SHELL (menu), menu_item);
-  g_signal_connect (G_OBJECT (menu_item), "activate", G_CALLBACK(on_close_tab), vterm);
-
-  return menu;
+	
+	gldi_menu_add_item (menu, D_("New Tab"), GTK_STOCK_NEW, G_CALLBACK(on_new_tab), NULL);
+	
+	gldi_menu_add_item (menu, D_("Rename this Tab"), GTK_STOCK_EDIT, G_CALLBACK(on_rename_tab), vterm);
+	
+	gldi_menu_add_item (menu, D_("Change this Tab's colour"), GTK_STOCK_COLOR_PICKER, G_CALLBACK(on_change_tab_color), vterm);
+	
+	gldi_menu_add_item (menu, D_("Close this Tab"), GTK_STOCK_CLOSE, G_CALLBACK(on_close_tab), vterm);
+	
+	return menu;
 }
 
 static gboolean applet_on_terminal_press_cb(GtkWidget *vterm, GdkEventButton *event, gpointer user_data)
 {
-	cd_debug ("%s ()\n", __func__);
 	if (event->button == 3)
 	{
 		GtkWidget *menu = _terminal_build_menu_tab (vterm);
@@ -441,6 +501,7 @@ static gboolean applet_on_terminal_press_cb(GtkWidget *vterm, GdkEventButton *ev
 			1,
 			gtk_get_current_event_time ());
 	}
+	gtk_window_present (GTK_WINDOW (myContainer->pWidget));
 	return FALSE;
 }
 static void applet_on_terminal_eof(VteTerminal *vterm,
@@ -515,8 +576,6 @@ static gchar * _terminal_get_tab_name (int iNumPage)
 	GtkWidget *vterm = gtk_notebook_get_nth_page (GTK_NOTEBOOK(myData.tab), iNumPage);
 	GtkWidget *pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), vterm);
 	GList *pTabWidgetList = gtk_container_get_children (GTK_CONTAINER (pTabLabelWidget));
-	GtkLabel *pLabel;
-	const gchar *cCurrentName;
 	if (pTabWidgetList != NULL && pTabWidgetList->data != NULL)
 	{
 		GtkLabel *pLabel = pTabWidgetList->data;
@@ -525,23 +584,27 @@ static gchar * _terminal_get_tab_name (int iNumPage)
 	}
 	return NULL;
 }
+
+static AtkObject *
+_get_dummy_accessible(GtkWidget *widget)
+{
+	return NULL;
+}
+
 void terminal_new_tab(void)
 {
 	//\_________________ On cree un nouveau terminal.
 	GtkWidget *vterm = vte_terminal_new();
-	//transparency enable, otherwise we cant change value after
-	//vte_terminal_set_background_transparent(VTE_TERMINAL(vterm), TRUE);
-	#if GTK_MINOR_VERSION >= 12
-	vte_terminal_set_opacity(VTE_TERMINAL(vterm), myConfig.transparency);
-	#endif
-	vte_terminal_set_emulation(VTE_TERMINAL(vterm), "xterm");
+	GTK_WIDGET_GET_CLASS (vterm)->get_accessible = _get_dummy_accessible;  // this is to prevent a bug in libvet2.90; it gives a warning, but it's better than a crash !
+	vte_terminal_set_emulation (VTE_TERMINAL(vterm), "xterm");
 	pid_t pid; 
 	#if (GLIB_MAJOR_VERSION > 2) || (GLIB_MAJOR_VERSION == 2 && GLIB_MINOR_VERSION >= 18)  // VTE_CHECK_VERSION doesn't exist in Hardy.
 		#if VTE_CHECK_VERSION(0,26,0)
+		const gchar *argv[] = {g_getenv ("SHELL"), NULL};
 		vte_terminal_fork_command_full (VTE_TERMINAL(vterm),
 			VTE_PTY_NO_LASTLOG | VTE_PTY_NO_UTMP | VTE_PTY_NO_WTMP,
 			"~/",
-			NULL,  // argv
+			(gchar**)argv,  // argv
 			NULL,  // envv
 			0,  // GSpawnFlags spawn_flags
 			NULL,  // GSpawnChildSetupFunc child_setup
@@ -581,8 +644,8 @@ void terminal_new_tab(void)
 	
 	cairo_dock_allow_widget_to_receive_data (vterm, G_CALLBACK (on_terminal_drag_data_received), NULL);
 
-	GtkWidget *pHBox = gtk_hbox_new (FALSE, 0);
-	
+	GtkWidget *pHBox = _gtk_hbox_new (0);
+
 	//\_________________ On choisit un nom qui ne soit pas deja present, de la forme " # n ".
 	int i, iNbPages = gtk_notebook_get_n_pages (GTK_NOTEBOOK(myData.tab));
 	GList *pTabNameList = NULL;
@@ -637,10 +700,10 @@ void terminal_new_tab(void)
 		0);
 	
 	gtk_widget_show_all (pHBox);
-	int num_new_tab = gtk_notebook_append_page(GTK_NOTEBOOK(myData.tab), vterm, pHBox);
-	GtkWidget *pNewTab = gtk_notebook_get_nth_page (GTK_NOTEBOOK(myData.tab), num_new_tab);
-	
 	gtk_widget_show(vterm);
+	int num_new_tab = gtk_notebook_append_page(GTK_NOTEBOOK(myData.tab), vterm, pHBox);
+	gtk_notebook_set_tab_reorderable (GTK_NOTEBOOK(myData.tab), vterm, TRUE);
+	
 	cd_message ("num_new_tab : %d", num_new_tab);
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (myData.tab), num_new_tab);
 	
@@ -667,7 +730,7 @@ static void _hide_show_tab_button (GtkNotebook *pNotebook, int iNumPage, gboolea
 	g_list_free (pTabWidgetList);
 }
 static void on_switch_page (GtkNotebook *pNotebook,
-	GtkNotebookPage *pNextPage,
+	GtkWidget *pNextPage,
 	guint iNextNumPage,
 	gpointer user_data)
 {
@@ -685,17 +748,25 @@ static GtkWidget * _terminal_find_clicked_tab_child (int x, int y)  // x,y relat
 	int iCurrentNumPage = gtk_notebook_get_current_page (GTK_NOTEBOOK (myData.tab));
 	pPageChild = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), iCurrentNumPage);
 	pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), pPageChild);
+	#if (GTK_MAJOR_VERSION < 3)
 	gtk_widget_get_child_requisition (pTabLabelWidget, &requisition);
+	#else
+	gtk_widget_get_preferred_size (pTabLabelWidget, &requisition, NULL);
+	#endif
 	iMaxTabHeight = requisition.height;
 	//g_print ("iMaxTabHeight : %d\n", iMaxTabHeight);
 	
 	int i, iNbPages = gtk_notebook_get_n_pages (GTK_NOTEBOOK (myData.tab));
-	gint src_x, src_y, dest_x, dest_y;
+	gint dest_x, dest_y;
 	for (i = 0; i < iNbPages; ++i)
 	{
 		pPageChild = gtk_notebook_get_nth_page(GTK_NOTEBOOK(myData.tab), i);
 		pTabLabelWidget = gtk_notebook_get_tab_label (GTK_NOTEBOOK(myData.tab), pPageChild);
+		#if (GTK_MAJOR_VERSION < 3)
 		gtk_widget_get_child_requisition (pTabLabelWidget, &requisition);
+		#else
+		gtk_widget_get_preferred_size (pTabLabelWidget, &requisition, NULL);
+		#endif
 		gtk_widget_translate_coordinates (myData.tab,
 			pTabLabelWidget,
 			x, y,
@@ -714,7 +785,7 @@ static gboolean on_button_press_tab (GtkWidget* pWidget,
 	GdkEventButton* pButton,
 	gpointer data)
 {
-	cd_debug ("%s (%d;%d)\n", __func__, (int)pButton->x, (int)pButton->y);
+	cd_debug ("%s (%d;%d)", __func__, (int)pButton->x, (int)pButton->y);
 	GtkWidget *vterm = _terminal_find_clicked_tab_child (pButton->x, pButton->y);
 	if (pButton->type == GDK_2BUTTON_PRESS)
 	{
@@ -754,14 +825,14 @@ static gboolean on_button_press_tab (GtkWidget* pWidget,
 }
 
 
-static gboolean on_button_press_dialog (GtkWidget *widget,
+/**static gboolean on_button_press_dialog (GtkWidget *widget,
 	GdkEventButton *pButton,
 	CairoDialog *pDialog)
 {
 	cd_message ("hide the dialog when clicking on it");
 	cairo_dock_hide_dialog (pDialog);
 	return TRUE;
-}
+}*/
 void terminal_build_and_show_tab (void)
 {
 	//\_________________ On cree un notebook.
@@ -783,21 +854,21 @@ void terminal_build_and_show_tab (void)
 	terminal_new_tab();
 	gtk_widget_show(myData.tab);
 
-	term_apply_settings();
+	///term_apply_settings();
 
 	//\_________________ On insere le notebook dans le container.
 	if (myDock)
 	{
 		myData.dialog = cd_terminal_build_dialog ();
-		g_signal_connect (G_OBJECT (myData.dialog->container.pWidget),
+		/**g_signal_connect (G_OBJECT (myData.dialog->container.pWidget),
 			"button-press-event",
 			G_CALLBACK (on_button_press_dialog),
-			myData.dialog);  // on le cache quand on clique dessus.
+			myData.dialog);*/  // on le cache quand on clique dessus.
 		cd_terminal_grab_focus ();
 	}
 	else
 	{
-		cairo_dock_add_interactive_widget_to_desklet (myData.tab, myDesklet);
+		gldi_desklet_add_interactive_widget (myDesklet, myData.tab);
 		CD_APPLET_SET_DESKLET_RENDERER (NULL);  // pour empecher le clignotement du au double-buffer.
 	}
 }
